@@ -12,8 +12,17 @@ optionflags = (doctest.NORMALIZE_WHITESPACE|
 
 def test_suite():
     suite = ZopeTestCase.FunctionalDocFileSuite(
-        'criteria.txt',
         'README.txt',
+        'criteria/list.txt',
+        'criteria/selection.txt',
+        'criteria/checkbox.txt',
+        'criteria/daterange.txt',
+        'criteria/comma.txt',
+        'criteria/boolean.txt',
+        'criteria/date.txt',
+        'criteria/path.txt',
+        'criteria/relativepath.txt',
+        'criteria/simpleint.txt',
         optionflags=optionflags,
         test_class=ptc.FunctionalTestCase)
     suite.layer = testing.formcriteria_layer
